==> ga4gh-rnaget-compliance-0.1.0.tar.gz: ga4gh-rnaget-compliance-0.1.0/README.md <==
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg?style=flat-square)](https://opensource.org/licenses/Apache-2.0)
[![Travis (.org) branch](https://img.shields.io/travis/ga4gh-rnaseq/rnaget-compliance-suite/master.svg?style=flat-square)](https://travis-ci.org/ga4gh-rnaseq/rnaget-compliance-suite)
[![Coverage Status](https://img.shields.io/coveralls/github/ga4gh-rnaseq/rnaget-compliance-suite.svg?style=flat-square)](https://coveralls.io/github/ga4gh-rnaseq/rnaget-compliance-suite)
[![Read the Docs](https://img.shields.io/readthedocs/rnaget-compliance-suite.svg?style=flat-square)](https://rnaget-compliance-suite.readthedocs.io/en/latest/)
![PyPI](https://img.shields.io/pypi/v/ga4gh-rnaget-compliance?style=flat-square)
[![Python 3.6](https://img.shields.io/badge/python-3.6%20|%203.7-blue.svg?style=flat-square)](https://www.python.org)

# RNAget Compliance Suite

The RNAget Compliance Suite determines a server's compliance with the
[RNAget API specification](https://github.com/ga4gh-rnaseq/schema/blob/master/rnaget.md) for serving RNAseq datasets. The specification, developed by
the [Global Alliance for Genomics and Health](https://www.ga4gh.org/), serves to provide a standardized API framework and data structure to allow for interoperability of datasets hosted at different institutions.

Please review the [RNAget Compliance Documentation](https://rnaget-compliance-suite.readthedocs.io/en/latest/) for instructions on how to 
prepare and test an RNAget-compliant server.

RNAget maintains an up-to-date report of the compliance status of its reference implementers. [Click here to view the latest report.](https://ga4gh-rnaseq.github.io/rnaget-compliance-suite/report/)

## Installation and Usage

Please review the [Compliance Documentation](https://rnaget-compliance-suite.readthedocs.io/en/latest/utility/installation.html) for 
installation and usage instructions.

==> ga4gh-rnaget-compliance-0.1.1.tar.gz: ga4gh-rnaget-compliance-0.1.1/README.md <==
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg?style=flat-square)](https://opensource.org/licenses/Apache-2.0)
[![Travis (.org) branch](https://img.shields.io/travis/ga4gh-rnaseq/rnaget-compliance-suite/master.svg?style=flat-square)](https://travis-ci.org/ga4gh-rnaseq/rnaget-compliance-suite)
[![Coverage Status](https://img.shields.io/coveralls/github/ga4gh-rnaseq/rnaget-compliance-suite.svg?style=flat-square)](https://coveralls.io/github/ga4gh-rnaseq/rnaget-compliance-suite)
[![Read the Docs](https://img.shields.io/readthedocs/rnaget-compliance-suite.svg?style=flat-square)](https://rnaget-compliance-suite.readthedocs.io/en/latest/)
![PyPI](https://img.shields.io/pypi/v/ga4gh-rnaget-compliance?style=flat-square)
[![Python 3.6](https://img.shields.io/badge/python-3.6%20|%203.7-blue.svg?style=flat-square)](https://www.python.org)

# RNAget Compliance Suite

The RNAget Compliance Suite determines a server's compliance with the
[RNAget API specification](https://github.com/ga4gh-rnaseq/schema/blob/master/rnaget.md) for serving RNAseq datasets. The specification, developed by
the [Global Alliance for Genomics and Health](https://www.ga4gh.org/), serves to provide a standardized API framework and data structure to allow for interoperability of datasets hosted at different institutions.

Please review the [RNAget Compliance Documentation](https://rnaget-compliance-suite.readthedocs.io/en/latest/) for instructions on how to 
prepare and test an RNAget-compliant server.

RNAget maintains an up-to-date report of the compliance status of its reference implementers. [Click here to view the latest report.](https://ga4gh-rnaseq.github.io/rnaget-compliance-suite/report/)

## Installation and Usage

Please review the [Compliance Documentation](https://rnaget-compliance-suite.readthedocs.io/en/latest/) for 
installation and usage instructions.

## Additional Resources

1. [PyPI](https://pypi.org/project/ga4gh-rnaget-compliance/) - The RNAget Compliance Utility is available on the Python Package Index (PyPI)
